==> siri_wave-1.0.2.tar.gz: CONTRIBUTING.md <==
# Contributing

_See also: [siri_wave's code of conduct](https://github.com/halildurmus/siri_wave/blob/main/CODE_OF_CONDUCT.md)_

First off, thanks for taking the time to contribute!

The following is a guideline for contributing to **siri_wave**. These are mostly
guidelines, not rules. Use your best judgment, and feel free to propose changes
to this document in a pull request.

## Getting Started

Make sure you have **Flutter** installed and on your path.

Follow these steps to clone **siri_wave** and set up the development
environment:

1. Clone the project: `git clone https://github.com/halildurmus/siri_wave.git`
2. Go into the cloned directory: `cd siri_wave`
3. Install all packages: `flutter packages get`

## Before You Contribute

### File an issue first!

If the work you intend to do is non-trivial, **it is necessary to [file an issue](https://github.com/halildurmus/siri_wave/issues/new/choose) before starting writing your code**.
This helps us and the community to discuss the issue and choose what is deemed to be the best solution.

### Checking your code's quality

After you have made your changes, you have to make sure your code works
correctly and meets our guidelines. Our guidelines are:
- Make sure the code passes the tests. To run tests, run `flutter test`.
- Make sure to run `flutter analyze` and resolve any warnings or errors.
- The code should be formatted correctly. To format your code you can run this
  command inside the project from the command line: `flutter format`.

## Creating a Pull Request

Congratulations! Your code meets all of our guidelines. Now you have to submit
a pull request (or PR for short) to us.

These are the steps you should follow when creating a PR:
- Make a descriptive title that summarizes what changes were in the PR.
- Link to issues that this PR will fix (if any).
- If your PR adds a feature or fixes a bug, it must add one or more tests.
- Change your code according to feedback (if any).

After you follow the above steps, your PR will hopefully be merged.
Thanks for contributing!

==> siri_wave-2.0.0.tar.gz: CONTRIBUTING.md <==
# Contributing

_See also: [siri_wave's code of conduct][code_of_conduct_link]_

First off, thanks for taking the time to contribute!

The following is a guideline for contributing to **siri_wave**. These are mostly
guidelines, not rules. Use your best judgment, and feel free to propose changes
to this document in a pull request.

## Getting Started

Make sure you have **Flutter** installed and on your path.

Follow these steps to clone **siri_wave** and set up the development
environment:

1. Clone the project: `git clone https://github.com/halildurmus/siri_wave.git`
2. Go into the cloned directory: `cd siri_wave`
3. Install all packages: `flutter packages get`

## Before You Contribute

### File an issue first!

If the work you intend to do is non-trivial, **it is necessary to
[file an issue][file_an_issue_link] before starting writing your code**. This
helps us and the community to discuss the issue and choose what is deemed
to be the best solution.

### Checking your code's quality

After you have made your changes, you have to make sure your code works
correctly and meets our guidelines. Our guidelines are:
- Make sure the code passes the tests. To run tests, run `flutter test`.
- Make sure to run `flutter analyze` and resolve any warnings or errors.
- The code should be formatted correctly. To format your code you can run this
  command inside the project from the command line: `flutter format`.

## Creating a Pull Request

Congratulations! Your code meets all of our guidelines. Now you have to submit
a pull request (or PR for short) to us.

These are the steps you should follow when creating a PR:
- Make a descriptive title that summarizes what changes were in the PR.
- Link to issues that this PR will fix (if any).
- If your PR adds a feature or fixes a bug, it must add one or more tests.
- Change your code according to feedback (if any).

After you follow the above steps, your PR will hopefully be merged.
Thanks for contributing!

[code_of_conduct_link]: https://github.com/halildurmus/siri_wave/blob/main/CODE_OF_CONDUCT.md
[file_an_issue_link]: https://github.com/halildurmus/siri_wave/issues/new
